from setuptools import setup, find_packages
from notdb_viewer import __version__ as v

# README.md
with open('README.md', 'r', encoding='utf-8') as readme_file:
    readme = readme_file.read()

packages = [
    'notdb_viewer.app',
    *find_packages()
]

setup(
    name='notdb_viewer',
    packages=packages,
    version=v,
    description='Viewer for NotDB Databases',
    package_dir={
        'app': 'notdb_viewer/app'
    },
    author='Nawaf Alqari',
    author_email='nawafalqari13@gmail.com',
    keywords=['db'],
    long_description=readme,
    long_description_content_type='text/markdown',
    entry_points={
    'console_scripts': [ 'notdb_viewer=notdb_viewer.__main__:main']
    },
    project_urls={
        'Documentation': 'https://github.com/nawafalqari/NotDB#readme',
        'Bug Tracker': 'https://github.com/nawafalqari/NotDB/issues',
        'Source Code': 'https://github.com/nawafalqari/NotDB/',
        'Discord': 'https://discord.gg/cpvynqk4XT'
    },
    license='MIT',
    url='https://github.com/nawafalqari/notdb/',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)


from flask import Flask, render_template, request
import pyonr
import notdb
from requests import get

def refresh_data(file:pyonr.Read) -> dict:
   return file.readfile

def get_class(obj):
   return type(obj)

def get_obj_class_name(obj):
   return type(obj)().__class__.__name__

def create_app():

   app = Flask(__name__)

   @app.route('/')
   def index():
      db = app.db
      file = app.file

      data = refresh_data(file)
      db_info = {}

      db_info['Secured with password'] = True if data.get('__password') else False
      db_info['documents'] = db.documents

      return render_template('viewer.html',
                              documents=db.get({}),
                              db_info=db_info,
                              host=db.host,
                              get_obj_class_name=get_obj_class_name,
                              get_class=get_class,
                              f=file)

   return app